@@ -6,14 +6,15 @@
 
 set -eu -o pipefail
 
-if [ "$#" -ne 3 ]; then
+if [ "$#" -ne 4 ]; then
   echo "$0: Invalid arguments" >&2
-  echo "Expect: $0 HOST_UID TARGET RELEASE" >&2
+  echo "Expect: $0 HOST_UID TARGET_FILE RELEASE TARGET" >&2
   exit 1
 fi
 HOST_UID="$1"
-TARGET="$2"
+TARGET_FILE="$2"
 RELEASE="$3"
+TARGET="$4"
 
 set -x
 
@@ -23,16 +24,22 @@ MIRROR='https://deb.debian.org/debian'
 echo " ****************************************************************** "
 echo " * Running grml-debootstrap"
 
+if [ "$TARGET" = 'RPI' ]; then
+  extra_buildopts=(--rpifile --non-free)
+else
+  extra_buildopts=(--vmfile)
+fi
+
 grml-debootstrap \
   --debug \
   --force \
-  --vmfile \
-  --vmsize 3G \
-  --target "$TARGET" \
+  "${extra_buildopts[@]}" \
+  --imagesize 3G \
+  --target "$TARGET_FILE" \
   --bootappend "console=ttyS0,115200 console=tty0 vga=791" \
   --password grml \
   --release  "$RELEASE" \
   --hostname "$RELEASE" \
   --mirror "$MIRROR"
 
-chown "$HOST_UID" "$TARGET"
+chown "$HOST_UID" "$TARGET_FILE"
