@@ -6,15 +6,16 @@
 
 set -eu -o pipefail
 
-if [ "$#" -ne 2 ]; then
+if [ "$#" -ne 3 ]; then
   echo "$0: Invalid arguments" >&2
-  echo "Expect: $0 VM_IMAGE VM_HOSTNAME" >&2
+  echo "Expect: $0 VM_IMAGE VM_HOSTNAME TARGET" >&2
   exit 1
 fi
 set -x
 
 VM_IMAGE="$1"
 VM_HOSTNAME="$2"
+TARGET="$3"
 
 TEST_PWD="$PWD"
 TEST_TMPDIR=$(mktemp -d)
@@ -28,7 +29,7 @@ bailout() {
     ps --pid="${QEMU_PID}" -o pid= | grep -q '.' && kill "${QEMU_PID:-}"
   fi
 
-  rm -rf "${TEST_TMPDIR}"
+  sudo rm -rf "${TEST_TMPDIR}"
 
   [ -n "${1:-}" ] && EXIT_CODE="$1" || EXIT_CODE=1
   exit "$EXIT_CODE"
@@ -72,17 +73,30 @@ declare -a qemu_command
 
 DPKG_ARCHITECTURE=$(dpkg --print-architecture)
 if [ "${DPKG_ARCHITECTURE}" = "amd64" ]; then
-    qemu_command=( qemu-system-x86_64 )
-    qemu_command+=( -machine q35 )
+  qemu_command=( qemu-system-x86_64 )
+  qemu_command+=( -machine q35 )
 elif [ "${DPKG_ARCHITECTURE}" = "arm64" ]; then
+  if [ "$TARGET" = 'RPI' ]; then
+    if ! rpi_bootdata="$(sudo "$TEST_PWD"/tests/extract-rpi-bootdata.sh "$VM_IMAGE")"; then
+      echo "E: could not extract RPi boot data" >&2
+      exit 1
+    fi
+    IFS='|' read rpi_kern rpi_initrd rpi_kerncmd <<< "$rpi_bootdata"
+    qemu_command=( qemu-system-aarch64 )
+    qemu_command+=( -machine "type=virt,gic-version=max,accel=kvm:tcg,highmem=off" )
+    qemu_command+=( -kernel "$rpi_kern" )
+    qemu_command+=( -initrd "$rpi_initrd" )
+    qemu_command+=( -append "$rpi_kerncmd" )
+  else
     cp /usr/share/AAVMF/AAVMF_VARS.fd efi_vars.fd
     qemu_command=( qemu-system-aarch64 )
     qemu_command+=( -machine "type=virt,gic-version=max,accel=kvm:tcg" )
     qemu_command+=( -drive "if=pflash,format=raw,unit=0,file.filename=/usr/share/AAVMF/AAVMF_CODE.no-secboot.fd,file.locking=off,readonly=on" )
     qemu_command+=( -drive "if=pflash,format=raw,unit=1,file=efi_vars.fd" )
+  fi
 else
-    echo "E: unsupported ${DPKG_ARCHITECTURE}"
-    exit 1
+  echo "E: unsupported ${DPKG_ARCHITECTURE}" >&2
+  exit 1
 fi
 qemu_command+=( -cpu max )
 qemu_command+=( -smp 2 )
